# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 布局
# @Time   : 2024-09-19 16:43
# @Author : 毛鹏
from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QFormLayout, QGridLayout, QWidget, QApplication
